@@ -3,8 +3,8 @@ from functools import partial
 from getpass import getpass
 from logging import Logger
 from sqlite3 import Cursor
-from typing import Any, Collection
-from typing import Mapping, Sequence, Union
+from typing import Any, Collection, Dict
+from typing import List, Mapping, Sequence, Union
 from typing import get_args as typing_get_args
 
 import psycopg2
@@ -15,7 +15,7 @@ from sshtunnel import SSHTunnelForwarder
 
 from tablecrow.tables.base import DatabaseTable, parse_record_values, random_open_tcp_port
 
-from ..utilities import parse_hostname, split_hostname_port
+from ..utilities import guard_generic_alias, parse_hostname, split_hostname_port
 
 SSH_DEFAULT_PORT = 22
 
@@ -43,11 +43,11 @@ class PostGresTable(DatabaseTable):
         hostname: str,
         table_name: str,
         database: str = None,
-        fields: {str: type} = None,
-        primary_key: Union[str, Sequence[str]] = None,
+        fields: Dict[str, type] = None,
+        primary_key: Union[str, List[str]] = None,
         crs: CRS = None,
         username: str = None,
-        users: [str] = None,
+        users: List[str] = None,
         logger: Logger = None,
         **kwargs,
     ):
@@ -268,7 +268,7 @@ class PostGresTable(DatabaseTable):
                 field_type = dict
 
             try:
-                field_type = self.FIELD_TYPES[field_type.__name__]
+                field_type = self.FIELD_TYPES[guard_generic_alias(field_type.__name__)]
             except KeyError:
                 raise TypeError(f'PostGres does not support type "{field_type}"')
 
@@ -279,7 +279,7 @@ class PostGresTable(DatabaseTable):
         return ', '.join(schema)
 
     @property
-    def remote_fields(self) -> {str: type}:
+    def remote_fields(self) -> Dict[str, type]:
         if not self.connected:
             raise ConnectionError(
                 f'no connection to {self.username}@{self.hostname}:{self.port}/{self.database}/{self.name}'
@@ -339,8 +339,8 @@ class PostGresTable(DatabaseTable):
         return connected
 
     def records_where(
-        self, where: Union[Mapping[str, Any], str, Sequence[str]]
-    ) -> [{str: Any}]:
+        self, where: Union[Mapping[str, Any], str, List[str]]
+    ) -> List[Dict[str, Any]]:
         if not self.connected:
             raise ConnectionError(
                 f'no connection to {self.username}@{self.hostname}:{self.port}/{self.database}/{self.name}'
@@ -372,8 +372,8 @@ class PostGresTable(DatabaseTable):
         return matching_records
 
     def records_intersecting(
-        self, geometry: BaseGeometry, crs: CRS = None, geometry_fields: [str] = None
-    ) -> [{str: Any}]:
+        self, geometry: BaseGeometry, crs: CRS = None, geometry_fields: List[str] = None
+    ) -> List[Dict[str, Any]]:
         if crs is None:
             crs = self.crs
 
@@ -407,7 +407,7 @@ class PostGresTable(DatabaseTable):
             for record in records
         ]
 
-    def insert(self, records: [{str: Any}]):
+    def insert(self, records: List[Dict[str, Any]]):
         if isinstance(records, dict):
             records = [records]
 
@@ -512,7 +512,7 @@ class PostGresTable(DatabaseTable):
                             )
         connection.close()
 
-    def delete_where(self, where: Union[Mapping[str, Any], str, Sequence[str]]):
+    def delete_where(self, where: Union[Mapping[str, Any], str, List[str]]):
         if not self.connected:
             raise ConnectionError(
                 f'no connection to {self.username}@{self.hostname}:{self.port}/{self.database}/{self.name}'
@@ -558,7 +558,7 @@ class PostGresTable(DatabaseTable):
             f'{", ".join(key + "=" + repr(value) for key, value in self.kwargs.items())})'
         )
 
-    def __where_clause(self, where: {str: Union[Any, list]}) -> (str, [Any]):
+    def __where_clause(self, where: Dict[str, Union[Any, List]]) -> (str, List):
         if (
             where is not None
             and not isinstance(where, Sequence)
@@ -622,9 +622,9 @@ class PostGresTable(DatabaseTable):
         return where_clause, where_values
 
 
-def database_tables(cursor: Cursor, user_defined: bool = True) -> [str]:
+def database_tables(cursor: Cursor, user_defined: bool = True) -> List[str]:
     """
-    List tables within the given database.
+    list of tables within the given PostGreSQL database
 
     :param cursor: psycopg2 cursor
     :return: list of table names
@@ -642,7 +642,7 @@ def database_tables(cursor: Cursor, user_defined: bool = True) -> [str]:
 
 def database_has_table(cursor: psycopg2._psycopg.cursor, table: str) -> bool:
     """
-    Whether the given table exists within the given database.
+    whether the given table exists within the given PostGreSQL database
 
     :param cursor: psycopg2 cursor
     :param table: name of table
@@ -659,7 +659,7 @@ def database_has_table(cursor: psycopg2._psycopg.cursor, table: str) -> bool:
 
 def database_table_is_inherited(cursor: psycopg2._psycopg.cursor, table: str) -> bool:
     """
-    Whether the given table is inherited.
+    whether the given PostGreSQL table is inherited
 
     :param cursor: psycopg2 cursor
     :param table: name of table
@@ -673,9 +673,9 @@ def database_table_is_inherited(cursor: psycopg2._psycopg.cursor, table: str) ->
     return cursor.fetchone()[0]
 
 
-def database_table_fields(cursor: psycopg2._psycopg.cursor, table: str) -> {str: str}:
+def database_table_fields(cursor: psycopg2._psycopg.cursor, table: str) -> Dict[str, str]:
     """
-    Get field names and data types of the given table, within the given database.
+    field names and data types of the given table, within the given PostGreSQL database
 
     :param cursor: psycopg2 cursor
     :param table: name of table
