@@ -7,7 +7,7 @@ from os import PathLike
 from pathlib import Path
 import re
 import sys
-from typing import Any, Collection, Iterable, Mapping, Union
+from typing import Any, Collection, Dict, Iterable, Mapping, Union
 
 from dateutil.parser import parse as parse_date
 from pyproj import CRS
@@ -16,7 +16,14 @@ from shapely.geometry import shape as shapely_shape
 from shapely.geometry.base import GEOMETRY_TYPES
 
 
-def read_configuration(filename: PathLike) -> {str: str}:
+def read_configuration(filename: PathLike) -> Dict[str, str]:
+    """
+    read a configuration file with `configparser`
+
+    :param filename: path to configuration
+    :return: dictionary mapping of configuration entries
+    """
+
     configuration_file = configparser.ConfigParser()
     configuration_file.read(filename)
     return {
@@ -27,6 +34,13 @@ def read_configuration(filename: PathLike) -> {str: str}:
 
 
 def repository_root(path: PathLike = None) -> Path:
+    """
+    get the root directory of the current Git repository
+
+    :param path: query path
+    :return: repository root directory
+    """
+
     if path is None:
         path = __file__
     if not isinstance(path, Path):
@@ -41,7 +55,7 @@ def repository_root(path: PathLike = None) -> Path:
 
 def split_hostname_port(hostname: str) -> (str, Union[str, None]):
     """
-    Split the given URL into host and port, assuming port is appended after a colon.
+    split the given URL into host and port, assuming port is appended after a colon
 
     :param hostname: hostname string
     :return: hostname and port (if found, otherwise `None`)
@@ -60,7 +74,14 @@ def split_hostname_port(hostname: str) -> (str, Union[str, None]):
     return hostname, port
 
 
-def parse_hostname(hostname: str) -> {str: str}:
+def parse_hostname(hostname: str) -> Dict[str, str]:
+    """
+    parse detailed connection information from the given URL
+
+    :param hostname: URL with connection information
+    :return: dictionary of hostname, port, username, and password
+    """
+
     username = None
     password = None
 
@@ -87,6 +108,55 @@ def parse_hostname(hostname: str) -> {str: str}:
     }
 
 
+def guard_generic_alias(generic_alias) -> type:
+    """
+    convert an instance of a subscripted `typing._GenericAlias` to a subscripted type
+    :param generic_alias: generic alias
+    :return: type
+
+    :example:
+    >>> from typing import List
+    >>> guard_generic_alias(List[str])
+    [str]
+
+    :example:
+    >>> from typing import Dict
+    >>> guard_generic_alias(Dict[str, float])
+    {str: float}
+
+    :example:
+    >>> from typing import Dict, Tuple
+    >>> guard_generic_alias({str: (Dict[int, str], str)})
+    {str: ({int: str}, str)}
+
+    """
+
+    if hasattr(generic_alias, '__origin__'):
+        type_class = generic_alias.__origin__
+        if hasattr(generic_alias, '__args__'):
+            members = generic_alias.__args__
+            if issubclass(type_class, Mapping):
+                members = [members]
+        else:
+            members = ()
+    elif isinstance(generic_alias, Collection) and not isinstance(
+        generic_alias, (EnumMeta, str)
+    ):
+        type_class = generic_alias.__class__
+        if issubclass(type_class, Mapping):
+            members = generic_alias.items()
+        else:
+            members = generic_alias
+    else:
+        return generic_alias
+
+    members = [guard_generic_alias(member) for member in members]
+    if type_class != generic_alias.__class__ or members != generic_alias:
+        return type_class(members)
+    else:
+        return generic_alias
+
+
 def convert_value(value: Any, to_type: type) -> Any:
     if isinstance(to_type, str):
         to_type = eval(to_type)
@@ -94,6 +164,8 @@ def convert_value(value: Any, to_type: type) -> Any:
     if isinstance(value, Enum):
         value = value.name
 
+    to_type = guard_generic_alias(to_type)
+
     if to_type is None:
         value = None
     elif isinstance(to_type, Collection):
